@@ -28,7 +28,7 @@ from datetime import datetime
 from pathlib import Path
 
 import pytest
-from torrentfile import TorrentFile, TorrentFileHybrid, TorrentFileV2
+from torrentfile.torrent import TorrentFile, TorrentFileHybrid, TorrentFileV2
 
 from torrentfileQt import alt_start
 
@@ -230,6 +230,8 @@ def ttorrent(request, dir2):
     args = {
         "path": dir2,
         "outfile": str(dir2) + "t.torrent",
+        "url_list": ["url1", "url2"],
+        "announce": ["url4", "url5"],
         "comment": "This is a comment",
         "source": "SomeSource",
         "private": 1,
@@ -239,3 +241,56 @@ def ttorrent(request, dir2):
     outfile, _ = torrent.write()
     yield outfile
     rmpath(outfile)
+
+
+class MockEvent:
+    """Imitate functionality of a QtEvent."""
+
+    def __init__(self, path):
+        """Construct event."""
+        self.path = path
+        self.accepted = False
+
+    def accept(self):
+        """Accept function."""
+        self.accepted = True
+
+    def ignore(self):
+        """Ignore event."""
+        self.accepted = False
+
+    class MimeData:
+        """Mock Qt MimeData class."""
+
+        def __init__(self, text):
+            """Construct mimeData class."""
+            self.txt = text
+            if self.txt == "":
+                self.hasUrls = False
+            else:
+                self.hasUrls = True
+
+        class URL:
+            """URL Mock object."""
+
+            def __init__(self, url):
+                """Construct URL Mock object."""
+                self.url = url
+
+            def toLocalFile(self):
+                """Convert URL to local path."""
+                return self.url
+
+        def urls(self):
+            """Return the text passed to constructor."""
+            return [self.URL(self.txt)]
+
+    def mime_data(self):
+        """Return a mock of Qt MimeData class."""
+        if not self.path:
+            mdata = self.MimeData("")
+        else:
+            mdata = self.MimeData(self.path)
+        return mdata
+
+    mimeData = mime_data
