@@ -18,8 +18,23 @@
 ##############################################################################
 """Init module for TorrentfileQt project."""
 
-from torrentfileQt.version import __version__
+import sys
+import ctypes
+
+from torrentfileQt.version import __version__, ASSETS
 from torrentfileQt.window import Application, Window, alt_start, start
 
+
+myappid = f"TorrentfileQt.{__version__}"
+if sys.platform == "win32":
+    ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)
+
 __author__ = "alexpdev"
-__all__ = ["Application", "Window", "alt_start", "start", "__version__"]
+__all__ = [
+    "Application",
+    "Window",
+    "alt_start",
+    "start",
+    "__version__",
+    "ASSETS",
+]
