@@ -22,17 +22,27 @@ Tab Widget containing all controls for creating a new .torrent file.
 User must provide the path to the directory containing the what the
 .torrent file will be created from.
 """
-# import json
 import os
 from pathlib import Path
 from threading import Thread
 
 from PySide6.QtCore import Qt
-from PySide6.QtWidgets import (QCheckBox, QComboBox, QFileDialog, QGridLayout,
-                               QHBoxLayout, QLabel, QLineEdit, QPlainTextEdit,
-                               QPushButton, QRadioButton, QSpacerItem,
-                               QToolButton, QWidget)
-from torrentfile import TorrentFile, TorrentFileHybrid, TorrentFileV2
+from PySide6.QtWidgets import (
+    QCheckBox,
+    QComboBox,
+    QFileDialog,
+    QGridLayout,
+    QHBoxLayout,
+    QLabel,
+    QLineEdit,
+    QPlainTextEdit,
+    QPushButton,
+    QRadioButton,
+    QSpacerItem,
+    QToolButton,
+    QWidget,
+)
+from torrentfile.torrent import TorrentFile, TorrentFileHybrid, TorrentFileV2
 from torrentfile.utils import path_piece_length
 
 from torrentfileQt.qss import pushButtonEdit
@@ -66,10 +76,10 @@ class CreateWidget(QWidget):
 
         self.path_label = QLabel("Path: ", parent=self)
         self.output_label = QLabel("Save To: ", parent=self)
-        self.version_label = QLabel("Meta Version: ", parent=self)
+        self.version_label = QLabel("Version: ", parent=self)
         self.comment_label = QLabel("Comment: ", parent=self)
-        self.announce_label = QLabel("Tracker URLs: ", parent=self)
-        self.web_seed_label = QLabel("Web-seed URLs:")
+        self.announce_label = QLabel("Trackers: ", parent=self)
+        self.web_seed_label = QLabel("Web-Seeds: ")
         self.source_label = QLabel("Source: ", parent=self)
         self.piece_length_label = QLabel("Piece Size: ", parent=self)
 
@@ -94,10 +104,13 @@ class CreateWidget(QWidget):
         self.spacer1 = QSpacerItem(150, 0)
         self.spacer2 = QSpacerItem(70, 0)
 
-        self.path_label.setAlignment(Qt.AlignmentFlag.AlignRight)
-        self.path_input.setAlignment(Qt.AlignmentFlag.AlignLeft)
         sizePolicy = self.path_input.sizePolicy()
         sizePolicy.setHorizontalPolicy(sizePolicy.MinimumExpanding)
+
+        self.announce_label.setAlignment(Qt.AlignmentFlag.AlignRight)
+        self.web_seed_label.setAlignment(Qt.AlignmentFlag.AlignRight)
+        self.path_label.setAlignment(Qt.AlignmentFlag.AlignRight)
+        self.path_input.setAlignment(Qt.AlignmentFlag.AlignLeft)
         self.path_input.setSizePolicy(sizePolicy)
         self.output_label.setAlignment(Qt.AlignmentFlag.AlignRight)
         self.output_input.setAlignment(Qt.AlignmentFlag.AlignLeft)
@@ -226,6 +239,11 @@ class SubmitButton(QPushButton):
         if announce:
             args["announce"] = announce
 
+        url_list = self.widget.web_seed_input.toPlainText()
+        url_list = [i for i in url_list.split("\n") if i]
+        if url_list:
+            args["url_list"] = url_list
+
         # Calculates piece length if not specified by user.
         outtext = os.path.realpath(self.widget.output_input.text())
         if outtext:
@@ -318,25 +336,16 @@ class BrowseFileButton(QPushButton):
             self.window.path_input.setText(path)
             self.window.output_input.setText(path + ".torrent")
             piece_length = path_piece_length(path)
-            if piece_length < (2 ** 20):
-                val = f"{piece_length//(2**10)}KB"
+            if piece_length < (2**20):
+                val = f"{piece_length//(2**10)} KiB"
             else:
-                val = f"{piece_length//(2**20)}MB"
+                val = f"{piece_length//(2**20)} MiB"
             for i in range(self.window.piece_length.count()):
                 if self.window.piece_length.itemText(i) == val:
                     self.window.piece_length.setCurrentIndex(i)
                     break
 
 
-# class ProfileButton(QPushButton):
-#     """Save the current fields values as a profile."""
-
-#     def __init__(self, parent=None):
-#         """Save current fields as a profile."""
-#         super().__init__(parent=parent)
-#         self.setText("Save Profile")
-
-
 class BrowseDirButton(QPushButton):
     """Browse filesystem folders for path."""
 
@@ -372,10 +381,10 @@ class BrowseDirButton(QPushButton):
                 piece_length = path_piece_length(path)
             except PermissionError:  # pragma: no cover
                 return
-            if piece_length < (2 ** 20):
-                val = f"{piece_length//(2**10)}KB"
-            else:   # pragma: no cover
-                val = f"{piece_length//(2**20)}MB"
+            if piece_length < (2**20):
+                val = f"{piece_length//(2**10)} KiB"
+            else:  # pragma: no cover
+                val = f"{piece_length//(2**20)} MiB"
             for i in range(self.window.piece_length.count()):
                 if self.window.piece_length.itemText(i) == val:
                     self.window.piece_length.setCurrentIndex(i)
@@ -393,26 +402,14 @@ class ComboBox(QComboBox):
         self.setEditable(False)
         self.profile_data = None
 
-    # @classmethod
-    # def profiles(cls, parent=None):
-    #     """Create a profiles combobox."""
-    #     box = cls(parent=parent)
-    #     if os.path.exists(os.path.join(os.getcwd(), "profiles.json")):
-    #         with open("profiles.json", "rt") as js:
-    #             profs = json.load(js)
-    #             box.profile_data = profs
-    #             for name in profs:
-    #                 box.addItem(name)
-    #     return box
-
     @classmethod
     def piece_length(cls, parent=None):
         """Create a piece_length combobox."""
         box = cls(parent=parent)
-        for exp in range(14, 26):
+        for exp in range(14, 28):
             if exp < 20:
-                item = str((2 ** exp) // (2 ** 10)) + "KB"
+                item = str((2**exp) // (2**10)) + " KiB"
             else:
-                item = str((2 ** exp) // (2 ** 20)) + "MB"
-            box.addItem(item, 2 ** exp)
+                item = str((2**exp) // (2**20)) + " MiB"
+            box.addItem(item, 2**exp)
         return box
