@@ -27,11 +27,18 @@ from pathlib import Path
 import pyben
 from PySide6.QtCore import Qt, Signal
 from PySide6.QtGui import QIcon
-from PySide6.QtWidgets import (QFileDialog, QGridLayout, QLabel, QLineEdit,
-                               QPushButton, QTreeWidget, QTreeWidgetItem,
-                               QWidget)
+from PySide6.QtWidgets import (
+    QFileDialog,
+    QGridLayout,
+    QLabel,
+    QLineEdit,
+    QPushButton,
+    QTreeWidget,
+    QTreeWidgetItem,
+    QWidget,
+)
 
-from torrentfileQt.qss import infoLineEdit
+from torrentfileQt.qss import infoLineEdit, infoLineEditLight
 
 ASSETS = os.environ["ASSETS"]
 
@@ -76,18 +83,18 @@ class TreeWidget(QTreeWidget):
                 if i + 1 == len(partials):
                     _, suffix = os.path.splitext(partial)
                     if suffix in [".mp4", ".mkv"]:
-                        iconpath = os.path.join(ASSETS, "icons", "video.png")
+                        iconpath = os.path.join(ASSETS, "video.png")
                     elif suffix in [".rar", ".zip", ".7z", ".tar", ".gz"]:
-                        iconpath = os.path.join(ASSETS, "icons", "archive.png")
+                        iconpath = os.path.join(ASSETS, "archive.png")
                     elif re.match(r"\.r\d+", suffix):
-                        iconpath = os.path.join(ASSETS, "icons", "archive.png")
+                        iconpath = os.path.join(ASSETS, "archive.png")
                     elif suffix in [".wav", ".mp3", ".flac", ".m4a", ".aac"]:
-                        iconpath = os.path.join(ASSETS, "icons", "music.png")
+                        iconpath = os.path.join(ASSETS, "music.png")
                     else:
-                        iconpath = os.path.join(ASSETS, "icons", "file.png")
+                        iconpath = os.path.join(ASSETS, "file.png")
                     item.setLength(length)
                 else:
-                    iconpath = os.path.join(ASSETS, "icons", "folder.png")
+                    iconpath = os.path.join(ASSETS, "folder.png")
                 icon = QIcon(iconpath)
                 item.setIcon(0, icon)
                 item.setText(1, partial)
@@ -109,7 +116,7 @@ class TreeItem(QTreeWidgetItem):
     def setLength(self, length):
         """Set length leaf for tree branches."""
         child = TreeItem(0)
-        icon = QIcon(os.path.join(ASSETS, "icons", "scale.png"))
+        icon = QIcon(os.path.join(ASSETS, "scale.png"))
         child.setIcon(0, icon)
         child.setText(1, f"Size: {length} (bytes)")
         self.setExpanded(True)
@@ -207,6 +214,53 @@ class InfoWidget(QWidget):
         self.dateCreatedEdit.setObjectName("dateCreatedEdit")
         self.contentsLabel.setObjectName("contentsLabel")
         self.contentsTree.setObjectName("contentsTree")
+        self.setAcceptDrops(True)
+
+    def clear(self):
+        """Clear widgets of previous input."""
+        widgets = [
+            self.contentsTree,
+            self.sourceEdit,
+            self.metaVersionEdit,
+            self.pathEdit,
+            self.nameEdit,
+            self.pieceLengthEdit,
+            self.sizeEdit,
+            self.privateEdit,
+            self.commentEdit,
+            self.trackerEdit,
+            self.totalPiecesEdit,
+            self.dateCreatedEdit,
+            self.createdByEdit,
+        ]
+        for widget in widgets:
+            widget.clear()
+
+    def dragEnterEvent(self, event):
+        """Drag enter event for widget."""
+        if event.mimeData().hasUrls:
+            self.data = event.mimeData()
+            event.accept()
+            return True
+        return event.ignore()
+
+    def dragMoveEvent(self, event):
+        """Drag Move Event for widgit."""
+        if event.mimeData().hasUrls:
+            self.data = event.mimeData()
+            event.accept()
+            return True
+        return event.ignore()
+
+    def dropEvent(self, event):
+        """Accept drop event for info widgit."""
+        urls = event.mimeData().urls()
+        path = urls[0].toLocalFile()
+        if os.path.exists(path):
+            kws = format_data(path)
+            self.fill(**kws)
+            return True
+        return False
 
     def fill(self, **kws):
         """Fill all child widgets with collected information.
@@ -214,6 +268,7 @@ class InfoWidget(QWidget):
         Args:
             kws (`dict`): key, value dictionary with keys as field labels.
         """
+        self.clear()
         self.pathEdit.setText(kws["path"])
         self.nameEdit.setText(kws["name"])
         self.commentEdit.setText(kws["comment"])
@@ -268,76 +323,8 @@ class SelectButton(QPushButton):
                 selectedFilter=None,
             )
         if path:
-            meta = pyben.load(path)
-            info = meta["info"]
-            keywords = {
-                "path": path,
-                "piece_length": info["piece length"]
-            }
-            # get meta version
-            if "meta version" not in info:
-                keywords["meta version"] = 1
-            elif "pieces" in info:
-                keywords["meta version"] = 3
-            else:
-                keywords["meta version"] = 2
-
-            # extract creator
-            if "created by" in meta:
-                keywords["created_by"] = meta["created by"]
-            else:
-                keywords["created_by"] = ""
-
-            # extract name comment and source
-            for kw in ["name", "comment", "source"]:
-                if kw in info:
-                    keywords[kw] = info[kw]
-                else:
-                    keywords[kw] = ""
-
-            # extract announce list
-            if "announce-list" in meta:
-                alst = [url for urlst in meta["announce-list"] for url in urlst]
-                keywords["announce"] = alst + [meta["announce"]]
-            else:
-                keywords["announce"] = [meta["announce"]]
-
-            # iterate through filelist
-            size = 0
-            if "files" in info:
-                contents = {}
-                for entry in info["files"]:
-                    contents[
-                        os.path.join(info["name"], *entry["path"])
-                    ] = entry["length"]
-                    size += entry["length"]
-                keywords["contents"] = contents
-
-            elif "file tree" in info:
-                contents = {}
-                for k, v in parse_filetree(info["file tree"]).items():
-                    contents[os.path.join(info["name"], k)] = v
-                    size += v
-                keywords["contents"] = contents
-            else:
-                keywords["contents"] = {info["name"]: info["length"]}
-                size = info["length"]
-
-            keywords["length"] = size
-
-            if "creation date" in meta:
-                date = datetime.fromtimestamp(meta["creation date"])
-                text = date.strftime("%B %d, %Y %H:%M")
-                keywords["creation_date"] = text
-            else:
-                keywords["creation_date"] = ""
-
-            if "private" in info:
-                keywords["private"] = "True"
-            else:
-                keywords["private"] = "False"
-
-            self.parent().fill(**keywords)
+            kws = format_data(path)
+            self.parent().fill(**kws)
 
 
 class Label(QLabel):
@@ -355,12 +342,92 @@ class Label(QLabel):
 class InfoLineEdit(QLineEdit):
     """Line Edit Widget."""
 
+    style = {"dark": infoLineEdit, "light": infoLineEditLight}
+
     def __init__(self, parent=None):
         """Constructor for line edit widget."""
         super().__init__(parent=parent)
+        self.window = parent.window
         self.setReadOnly(True)
+        self.theme = "dark"
         self.setStyleSheet(infoLineEdit)
         self.setDragEnabled(True)
+        self.window.ThemeChanged.connect(self.change_stylesheet)
+
+    def change_stylesheet(self):
+        """Change the stylesheet with theme changes."""
+        self.theme = "light" if self.theme == "dark" else "dark"
+        self.setStyleSheet(self.style.get(self.theme))
+
+
+def format_data(path):
+    """Format meta data from torrent file after decoding."""
+    meta = pyben.load(path)
+    info = meta["info"]
+    keywords = {"path": path, "piece_length": info["piece length"]}
+    # get meta version
+    if "meta version" not in info:
+        keywords["meta version"] = 1
+    elif "pieces" in info:
+        keywords["meta version"] = 3
+    else:
+        keywords["meta version"] = 2
+
+    # extract creator
+    if "created by" in meta:
+        keywords["created_by"] = meta["created by"]
+    else:
+        keywords["created_by"] = ""
+
+    # extract name comment and source
+    for kw in ["name", "comment", "source"]:
+        if kw in info:
+            keywords[kw] = info[kw]
+        else:
+            keywords[kw] = ""
+
+    # extract announce list
+    if "announce-list" in meta:
+        alst = [url for urlst in meta["announce-list"] for url in urlst]
+        keywords["announce"] = alst + [meta["announce"]]
+    else:
+        keywords["announce"] = [meta["announce"]]
+
+    # iterate through filelist
+    size = 0
+    if "files" in info:
+        contents = {}
+        for entry in info["files"]:
+            contents[os.path.join(info["name"], *entry["path"])] = entry[
+                "length"
+            ]
+            size += entry["length"]
+        keywords["contents"] = contents
+
+    elif "file tree" in info:
+        contents = {}
+        for k, v in parse_filetree(info["file tree"]).items():
+            contents[os.path.join(info["name"], k)] = v
+            size += v
+        keywords["contents"] = contents
+    else:
+        keywords["contents"] = {info["name"]: info["length"]}
+        size = info["length"]
+
+    keywords["length"] = size
+
+    if "creation date" in meta:
+        date = datetime.fromtimestamp(meta["creation date"])
+        text = date.strftime("%B %d, %Y %H:%M")
+        keywords["creation_date"] = text
+    else:
+        keywords["creation_date"] = ""
+
+    if "private" in info:
+        keywords["private"] = "True"
+    else:
+        keywords["private"] = "False"
+    return keywords
 
 
 def denom(num):
