@@ -1,5 +1,5 @@
 ##############################################################################
-# Copyright 2020 AlexPDev
+# Copyright 20** AlexPDev
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,4 +15,19 @@
 ##############################################################################
 """Application version id tag."""
 
-__version__ = "0.2.7"
+import os
+
+
+__version__ = "0.3.5"
+
+
+def _conf():
+    """Create some enviornment variables."""
+    parent = os.path.dirname(__file__)
+    assets = os.path.join(parent, "assets")
+    path = os.path.relpath(assets, ".")
+    return path
+
+
+ASSETS = str(_conf())
+os.environ["ASSETS"] = ASSETS
